==> nextcloud-app-contacts-3.1.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/fa.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "مخاطبین",
    "All contacts" : "تمام مخاطبین",
    "Details" : "جزئیات",
    "Loading" : "در حال بار گزاری",
    "Name" : "نام",
    "Company" : "شرکت",
    "Title" : "عنوان",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Groups" : "گروه ها",
    "New contact" : "مخاطب جدید",
    "No results" : "نتیجه ای یافت نشد",
    "Last modified" : "آخرین اصلاح شده",
    "Rename" : "تغییرنام",
    "Enabled" : "فعال شده",
    "Disabled" : "غیرفعال شده",
    "Copy link" : "کپی کردن لینک",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "can edit" : "توانایی ویرایش",
    "Importing into" : "در حال وارد کردن به",
    "Import into" : "وارد کردن به",
    "Address book name" : "نام دفترچه آدرس",
    "First name" : "نام",
    "Last name" : "نام‌خانوادگی",
    "Display name" : "نام جهت نمایش",
    "Not grouped" : "گروه بندی نشده",
    "Nickname" : "نام مستعار",
    "Detailed name" : "نام کامل",
    "Additional names" : "نام های دیگر",
    "Prefix" : "پیشوند",
    "Suffix" : "پسوند",
    "Notes" : "یادداشت ها",
    "Website" : "وب‌سایت",
    "Location" : "محل",
    "Federated Cloud ID" : "Federated Cloud شناسه",
    "Home" : "خانه",
    "Work" : "کار",
    "Other" : "دیگر",
    "Address" : "آدرس",
    "Post office box" : "صندوق پستی محل کار",
    "City" : "شهر",
    "State or province" : "استان",
    "Postal code" : "کد پستی",
    "Country" : "کشور",
    "Birthday" : "روزتولد",
    "Anniversary" : "سالگرد",
    "Date of death" : "تاریخ فوت",
    "Email" : "پست الکترونیکی",
    "Instant messaging" : "پیام رسانی فوری",
    "Phone" : "شماره تلفن",
    "Mobile" : "موبایل",
    "Fax" : "دورنگار:",
    "Fax home" : "دورنگار منزل",
    "Fax work" : "دورنگار محل کار",
    "Pager" : "صفحه",
    "Voice" : "صدا",
    "Social network" : "شبکه اجتماعی",
    "Relationship" : "رابطه",
    "Spouse" : "همسر",
    "Child" : "فرزند",
    "Mother" : "مادر",
    "Father" : "پدر",
    "Parent" : "والدین",
    "Brother" : "برادر",
    "Sister" : "خواهر",
    "Relative" : "مرتبط",
    "Friend" : "دوست",
    "Colleague" : "کالج",
    "Manager" : "مدیر",
    "Assistant" : "راهنما",
    "Contact" : "مخاطب",
    "Gender" : "جنسیت",
    "Female" : "مؤنث",
    "Male" : "مذکر",
    "None" : "هیچ‌کدام",
    "Unknown" : "نامشخص"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-contacts-3.3.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/fa.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "مخاطبین",
    "All contacts" : "تمام مخاطبین",
    "Details" : "جزئیات",
    "Invalid image" : "عکس نامعتبر",
    "Loading" : "در حال بار گزاری",
    "Name" : "نام",
    "Company" : "شرکت",
    "Title" : "عنوان",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Cancel" : "لغو",
    "Address book" : "دفترچه آدرس",
    "Groups" : "گروه ها",
    "New contact" : "مخاطب جدید",
    "Select Date" : "تاریخ را انتخاب کنید",
    "No results" : "نتیجه ای یافت نشد",
    "Last modified" : "آخرین اصلاح شده",
    "Rename" : "تغییرنام",
    "Enabled" : "فعال شده",
    "Disabled" : "غیرفعال شده",
    "Copy link" : "کپی کردن لینک",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "can edit" : "توانایی ویرایش",
    "Address book name" : "نام دفترچه آدرس",
    "First name" : "نام",
    "Last name" : "نام‌خانوادگی",
    "Display name" : "نام جهت نمایش",
    "Not grouped" : "گروه بندی نشده",
    "Nickname" : "نام مستعار",
    "Detailed name" : "نام کامل",
    "Additional names" : "نام های دیگر",
    "Prefix" : "پیشوند",
    "Suffix" : "پسوند",
    "Notes" : "یادداشت ها",
    "Website" : "وب‌سایت",
    "Location" : "محل",
    "Federated Cloud ID" : "Federated Cloud شناسه",
    "Home" : "خانه",
    "Work" : "کار",
    "Other" : "دیگر",
    "Address" : "آدرس",
    "Post office box" : "صندوق پستی محل کار",
    "City" : "شهر",
    "State or province" : "استان",
    "Postal code" : "کد پستی",
    "Country" : "کشور",
    "Birthday" : "روزتولد",
    "Anniversary" : "سالگرد",
    "Date of death" : "تاریخ فوت",
    "Email" : "پست الکترونیکی",
    "Instant messaging" : "پیام رسانی فوری",
    "Phone" : "شماره تلفن",
    "Mobile" : "موبایل",
    "Fax" : "دورنگار:",
    "Fax home" : "دورنگار منزل",
    "Fax work" : "دورنگار محل کار",
    "Pager" : "صفحه",
    "Voice" : "صدا",
    "Social network" : "شبکه اجتماعی",
    "Relationship" : "رابطه",
    "Spouse" : "همسر",
    "Child" : "فرزند",
    "Mother" : "مادر",
    "Father" : "پدر",
    "Parent" : "والدین",
    "Brother" : "برادر",
    "Sister" : "خواهر",
    "Relative" : "مرتبط",
    "Friend" : "دوست",
    "Colleague" : "کالج",
    "Manager" : "مدیر",
    "Assistant" : "راهنما",
    "Contact" : "مخاطب",
    "Gender" : "جنسیت",
    "Female" : "مؤنث",
    "Male" : "مذکر",
    "None" : "هیچ‌کدام",
    "Unknown" : "نامشخص",
    "An error occurred" : "خطایی روی داد"
},
"nplurals=2; plural=(n > 1);");
